Changelog
=========

2.0 (27/03/2023)
------------------

- Drop support Python < 3.8. [csanahuja]
- Update widgets to Boostrap 5 and Plone 6 [csanahuja]
- Update dependencies [csanahuja]


1.7 (17/03/2023)
------------------

New features:

- Add new OSMap widget with advanced features
  [abosch]


1.6.7 (11/11/2022)
------------------

Fixes:

- Fix icon widget display
  [caguilo]


1.6.6 (06/05/2022)
------------------

Fixes:

- Fix colour widget display template when multiple widgets
  [csanahuja]


1.6.5 (07/04/2022)
------------------

Fixes:

- Fix icon widget on datagrid fields
  [csanahuja]


1.6.4 (11/11/2020)
------------------

Fixes:

- Fix all widgets for Plone 5.2.2
  [csanahuja]

1.6.3 (11/11/2020)
------------------

Fixes:

- Fix osmap widget for Plone 5.2.2
  [csanahuja]

1.6.2 (10/01/2020)
------------------

New features:

- Add attribute on icon_input.pt script so we can keep it with diazo
  [csanahuja]

1.6.1 (13/12/2019)
------------------

Fixes:

- Fix missing/wrong translations
  [csanahuja]

1.6 (03/12/2019)
------------------

New features:

- Modified OSMap widget so we use require to load leaflet
  [csanahuja]

Fixes:

- Fix OSMap widget when using plone modal
  [csanahuja]

1.5 (05/11/2019)
------------------

Fixes:

- Fix IOSMapBehavior wrong parent class
  [csanahuja]

1.4 (10/10/2019)
------------------

New features:

- Add default view for each contenttype
  [csanahuja]

Fixes:

- Fix coordinates controlpanel previously with wrong prefix
  [csanahuja]

1.3.1 (09/10/2019)
------------------

- Improved coverage
  [csanahuja]

1.3 (08/10/2019)
------------------

New features:

- Add coordinates controlpanel and profile to install
  [csanahuja]
- Added converter to osmap widget
  [csanahuja]

Fixes:

- Minor fixes and translations
  [csanahuja]

1.2 (07/10/2019)
------------------

New features:

- Make link not reaquired
  [csanahuja]
- Added new default view to content-types to avoid failing when no link
  [csanahuja]

Fixes:

- Correct typo in all behaviors name registration
  [csanahuja]


1.1 (18/09/2019)
------------------

New features:

- Added field and widget for osmap
  [csanahuja]

1.0 (08/08/2019)
------------------

New features:

- Initial release.
  [csanahuja]
- Added content types: Banner, Slider, Icon, Announcement
  [csanahuja]
- Added fields and widgets for icons and colour
  [csanahuja]
- Added behaviors
  [csanahuja]
 

1.0a1 (unreleased)
------------------

- Initial release.
  [csanahuja]
